/*******
If the option "secure connection" in preferences is enabled you can only access documents which have been created using the connection. Via connenction documents can only created by "readDataformText" and "openFile". Also if "secure connection" is enabled you can not write to disk via connenction.
********/

typedef enum {disable_Att, enable_Att, dontchange_Att} alterAttType;

@protocol AbscissaReceiving

- (void) waitForEmptyReply;

- (oneway void)readDataformText:(const char *)textString 
	of:(const char *)document 
	source:(const char *)tableName 
	doRangeOverAll:(BOOL)flag 
	appendToExistingData:(BOOL)join;
	
- (oneway void)setXRangeOf:(const char *)documentName
	xmin:(double)Xmin
	xmax:(double)Xmax;

- (oneway void)setYRangeOf:(const char *)documentName
	ymin:(double)Ymin
	ymax:(double)Ymax;
	
- (oneway void)setLocalRangeOf:(const char *)documentName 
	XorYAxis:(BOOL)trueForX;

- (void) getXRangeOf:(const char *)documentName
	xmin:(out double*)Xmin
	xmax:(out double*)Xmax;
	
- (void) getYRangeOf:(const char *)documentName
	ymin:(out double*)Ymin
	ymax:(out double*)Ymax;
	
- (oneway void)deleteAllCurvesOf:(const char *)documentName;

- (oneway void)closeDocument:(const char *)documentName
	askForSave:(BOOL)ask;

- (oneway void)newDocument:(const char *)documentName;

- (oneway void)saveDocument:(const char *)documentName 
	as:(const char *)fileName
	binary:(BOOL)notAscii;
	/* saveDocument is disabled for "secure connection" */

- (oneway void)savePicture:(const char *)documentName
	as:(const char *)fileName;
	/* savePicture is disabled for "secure connection" */

- (oneway void)openFile:(const char *)documentName
	file:(const char *)fileName
	doRangeOverAll:(BOOL)flag;

- (oneway void)setXTitleOf:(const char *)documentName
	to:(const char *)RTFtext;
	
- (oneway void)setYTitleOf:(const char *)documentName
	to:(const char *)RTFtext;
	
- (oneway void)setTextOf:(const char *)documentName
	to:(const char *)RTFtext
	at_X:(double)x
	at_Y:(double)y;
	
- (oneway void)selectCurvesOf:(const char *)documentName
	sourceName:(const char *)source   // source=="" means all source
	table:(int)table                  // table ==-1 means all tables
	column:(const char *)column       // column=="" means all column
	appendSelection:(BOOL) append;
	
- (oneway void)selectCurvesOf:(const char *)documentName
	regexSourceName:(const char *)source
	table:(int)table                  // table==-1 means all tables
	regexColumn:(const char *)column
	appendSelection:(BOOL) append;
	
- (oneway void) setAttributesOfSelectionOf:(const char *)documentName
	line:(alterAttType)line
	stepped:(alterAttType)stepped
	yerr:(alterAttType)yerr
	xerr:(alterAttType)xerr
	dash:(alterAttType)dash
	fill:(alterAttType)fill
	topX:(alterAttType)topX
	rightY:(alterAttType)rightY
	marker:(alterAttType)marker
	sym:(alterAttType)sym;
	
- (oneway void) markSelectionAsFitDataOf:(const char *)documentName;

- (oneway void) deleteSelectedCurvesOf:(const char *)documentName;

- (oneway void) sortSelectedCurvesBySelection:(const char *)documentName
	ascending:(BOOL)flag;
	
- (oneway void) sortSelectedCurvesByXdata:(const char *)documentName;

- (oneway void) swapSelectedCurvesWithXdata:(const char *)documentName;

- (oneway void) createCurveAtSelectionOf:(const char *)documentName
	minx:(double)minx
	maxx:(double)maxx
	incx:(double)incx
	miny:(double)miny
	incy:(double)incy;

- (int) indexOfCurveNameOf:(const char *)documentName
	source:(const char *)source
	table:(int)table                  // table==-1 means all tables
	column:(const char *)column;
	
- (int) indexOfCurveNameOf:(const char *)documentName
	regexSource:(const char *)source
	table:(int)table                  // table==-1 means all tables
	regexColumn:(const char *)column;

- (oneway void) searchMaximaOfSelectionOf:(const char *)documentName
	searchMaxima:(BOOL)searchMaxima
	searchMinima:(BOOL)searchMinima
	minwidth:(int)minwidth
	minheight:(double)minheight;

- (oneway void) setFormulaOf:(const char *)documentName
	formulaText:(const char *)text;

- (oneway void) readFormulaParameterOf:(const char *)documentName
	parameterList:(const char *)text;

- (char *) formulaTextOf:(const char *)documentName;  
          /* the client should free the result pointer alfter usage */

- (char *) formulaParameterListOf:(const char *)documentName;
          /* the client should free the result pointer alfter usage */
	
- (char *) documentNameOfFrontWindow;
          /* The client should free the result pointer.              */
		  /* If the preference "secure connection" is enabled, only  */
		  /* connenction documents will be returned. */
		  /* Returns "" if there is no window. */

- (oneway void) modifyDataOf:(const char *)documentName
	Ydata:(BOOL)Ydata;
	
- (oneway void) showCurveOf:(const char *)documentName;

- (int) startFitOf:(const char *)documentName 
	iterations:(out int *)it 
	lambda:(out double *)l 
	chiq:(out double *)c;
		/* returns 0 if OK */
	
- (oneway void) display:(const char *)documentName
	doRangeOverAll:(BOOL)flag;

@end